DiagnosticCode

Struct DiagnosticCode 

pub struct DiagnosticCode<D = DefaultDiscriminant> {
    pub discriminant: D,
    /* private fields */
}
A code that identifies a given kind of diagnostic.

These are meant to be used by users as unchanging identifiers by which they can look up more detailed information about the diagnostic.

Fields

discriminant: D

The numeric discriminant.

Implementations

Source

impl<D> DiagnosticCode<D>

pub fn new(prefix: [u8; 3], discriminant: D) -> Result<Self, Utf8Error>

Constructs a new DiagnosticCode.

Errors

If prefix is not valid UTF-8, an error variant will be returned.

See Also
pub const unsafe fn new_unchecked(prefix: [u8; 3], discriminant: D) -> Self

Constructs a new DiagnosticCode.

Safety

The caller is responsible for ensuring prefix is valid UTF-8. For a safe alternative, see new.

See Also
pub const fn prefix_bytes(&self) -> &[u8; 3]

Gets this code’s prefix as a slice of raw, UTF-8-encoded bytes.

See Also
pub const fn prefix_str(&self) -> &str

Gets this code’s prefix as a string slice.

See Also