pub enum Context<S> {
Label(Label<S>),
Note(Box<str>),
Help(Box<str>),
}Expand description
Some contextual information about a diagnostic.
Consumers of this crate generally should not need to explicitly use this type. It is only made public to provide the ability to filter diagnostics by their context on the off-chance that is necessary.
Variants
Label(Label<S>)
A labeled subspan of a diagnostic, optionally with an attached message.
Note(Box<str>)
A message that provides specialized information concerning the overall diagnostic.
Help(Box<str>)
Advice concerning the overall diagnostic.
Implementations
Sourceimpl<S> Context<S>
impl<S> Context<S>