ColorPalette

Struct ColorPalette 

pub struct ColorPalette {
    pub special: Color,
    pub random: [Color; 4],
}
A selection of colors to use when building diagnostics.

Fields

special: Color

The primary color to highlight diagnostics with when there is not a more specific option.

random: [Color; 4]

Colors with no assigned meaning.

Implementations

Source

impl ColorPalette

pub const N_RANDOM_COLORS: usize = 4

The number of colors in Self::random.

pub const DEFAULT_RANDOM_COLORS: [Color; 4]

The default value of Self::random.

pub const DEFAULT_SPECIAL_COLOR: Color

The default value of Self::special.

pub const fn new() -> Self

Constructs a new ColorPalette using the provided color generator.

Builder methods can be chained with this one to further customize the colors.

pub const fn with_special(&mut self, color: Color) -> &mut Self

Changes the special color.

pub const fn with_random_colors(&mut self, colors: [Color; 4]) -> &mut Self

Changes the random colors.

pub fn with_regenerated_random_colors( &mut self, color_gen: &mut ColorGenerator, ) -> &mut Self

Regenerates the random colors using the provided color generator.