pub struct DiagnosticCode<D = DefaultDiscriminant> {
pub discriminant: D,
/* private fields */
}Expand description
A code that identifies a given kind of diagnostic.
These are meant to be used by users as unchanging identifiers by which they can look up more detailed information about the diagnostic.
Fields
discriminant: DThe numeric discriminant.
Implementations
Sourceimpl<D> DiagnosticCode<D>
impl<D> DiagnosticCode<D>
Sourcepub fn new(prefix: [u8; 3], discriminant: D) -> Result<Self, Utf8Error>
pub fn new(prefix: [u8; 3], discriminant: D) -> Result<Self, Utf8Error>
Constructs a new DiagnosticCode.
Errors
If prefix is not valid UTF-8, an error variant will be returned.
See Also
Sourcepub const unsafe fn new_unchecked(prefix: [u8; 3], discriminant: D) -> Self
pub const unsafe fn new_unchecked(prefix: [u8; 3], discriminant: D) -> Self
Constructs a new DiagnosticCode.
Safety
The caller is responsible for ensuring prefix is valid UTF-8. For a safe alternative, see
new.
See Also
Sourcepub const fn prefix_bytes(&self) -> &[u8; 3]
pub const fn prefix_bytes(&self) -> &[u8; 3]
Sourcepub const fn prefix_str(&self) -> &str
pub const fn prefix_str(&self) -> &str